<#-- utilities for SPC report (RTF and PDF) -->
<#global languageCode = "en">

<#assign locale = "en">

<#-- initiate the main variables -->
<@com.initializeMainVariables/>

<#-- globalize the language Locale, deriving from the main FTL, so that it can be used to indicate which language property file to use -->
<#global languageLocale = "languageLocale">

<#-- if doc type or subtype change, only change it here -->
<#assign mainMixtureCompositionList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />
<#assign mainMixtureCompositionSummaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_SUMMARY", "ProductSummaryComposition") />
<#assign supplierList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "Suppliers") />
<#assign summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_SUMMARY", "BioSummaryEvaluation") />	
<#assign protectionMeasuresList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "ProtectionMeasures") />	
<#assign usesList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "BioIntendedUsesExposure") />	
<#assign ghsList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "Ghs") />	
<#assign summaryAndEvaluationList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_SUMMARY", "BioSummaryEvaluation") />	
<#assign otherInformationList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "OtherInformationSPC") />	
<#assign sitesList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "Sites") />	


    <#assign tableID = {
    "table_id_1":"Trade name(s) of the product",
    "table_id_2":"Qualitative and quantitative information on the composition of the product",    
    "table_id_3":"Authorisation holder",
    "table_id_4":"Hazard and precautionary statements",
    "table_id_5":"Use description",
    "table_id_6":"Manufacturer(s) of the product",
    "table_id_7":"Manufacturer(s) of the active substance(s)",
    "table_id_8":"Formulation types product",
    "table_id_1_family":"Family name",   
    "table_id_2_family":"Product type",
    "table_id_3_family":"Qualitative and quantitative information on the composition of the family summary", 
    "table_id_4_family":"Formulation types summary",

    "table_id_5_family":"Qualitative and quantitative information on the composition of the meta spc",
    "table_id_6_family":"Formulation types meta spc",
    "table_id_7_family":"Meta SPC Hazard and precautionary statements",
    "table_id_8_family":"Meta SPC Use description",
    "table_id_9_family":"Meta SPC Other information",
    "table_id_10_family":"Meta SPC Product composition",
    "table_id_11_family":"Meta SPC Product composition additional",
    
    "table_id_12_family":"Meta SPC identifier",
    "table_id_13_family":"Suffix to the authorisation number",
    "table_id_14_family":"Product type(s)"
  }/>

<#-- This is the macro to use in prod, when all macros point here -->
<#-- This defines a macro called staticTextTest and a function called getStaticText that are used to retrieve static text values based on a given key and language locale -->
<#-- The staticTextTest macro is called with a parameter textKey that corresponds to a specific text value in the tocStaticText map defined later in the code. This macro also includes an optional metaSPCcounter parameter that can be used to provide additional information -->
<#macro staticText textKey metaSPCcounter="">
<#compress>
	<#-- a globally defined language locale comes from the Dossier header -->
	${getStaticText(textKey, languageLocale)} ${metaSPCcounter}
 </#compress>
</#macro>

<#-- Returns the localized text that is specific for this template -->
<#macro staticTextOther textKey metaSPCcounter="">
<#compress>
	  ${getotherStaticText(textKey, languageLocale)} ${metaSPCcounter}
</#compress>
</#macro>

<#-- The getStaticText function takes two parameters: textKey and languageLocale. 
It first checks if the language locale is provided and exists in the tocStaticText map. 
If so, it retrieves the text resources associated with that locale. If not, it defaults to the English locale. 
It then retrieves the text associated with the given textKey in the text resources, or an empty string if it does not exist. The function returns the text-->
<#function getStaticText textKey languageLocale>
  <#if languageLocale?has_content && textKey?has_content>
    <#local textResources = iuclid.text('${textKey}', '${languageLocale}', 'properties/localizations') />
  <#else>
       <#local textResources = iuclid.text('', 'en', 'properties/localizations') />
  </#if>  
  <#return textResources />
</#function>

<#-------------------------------------------------->
<#-- Common sections in single and family reports -->
<#-------------------------------------------------->

<#macro manufacturerOfTheProduct>

<!--
List sites
List site refs
List legal refs
If content in legal refs, output legal ref info and site ref info
If not content in legal refs, List legal refs and only output legal ref info
-->

  <#assign linkedLe = []/>
  <#assign supplierKey = [] />
  <#assign mysupplierskey = [] />
  <#assign mysite = [] />  

  <#list supplierList as suppliers>
  <#if suppliers?has_content>
  <#assign supplierKey = supplierKey + [suppliers]/>

    <#local linkedLe = iuclid.getDocumentForKey(suppliers.ManufacturerImportForm.LegalEntity)/>
    <#if linkedLe?has_content>
    <#assign mysupplierskey = mysupplierskey + [linkedLe]/>

      <#assign part1Table1Cell1><@staticText "part_1_table1_4_cell1_table1_5_cell_2_family_table1_3_table1_4_cell1_single" /></#assign>
      <#assign part1Table1Cell2><@staticText "part_1_table1_4_cell2_table1_5_cell_3_family_table1_3_table1_4_cell1_single" /></#assign>
      <#assign part1Table1Cell3><@staticText "part_1_table1_4_cell3_table1_5_cell_4_family_table1_3_table1_4_cell1_single" /></#assign>
      <@macroForPopulatingLegalEntity linkedLe "${tableID.table_id_6}"/>
      <@verticalHeaderTable linkedLe isMoreThanOneDoc(supplierKey) _subject linkedLe "headerPlaceholder" "${part1Table1Cell1}" "${part1Table1Cell2}" "${part1Table1Cell3}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "twoColTable" "${tableID.table_id_6}"/>   
  
    </#if>
  </#if>
  </#list>
</#macro>

  <#-- active substance manufacturer and location --------------------------------->
  <#-- iterate through active substances of both summary and product -------------->
  <#-- fetch manufacturer info (supplier) ready for checking location (LE match) -->
  <#-- each active substance names is also fetched -------------------------------->

<#macro suppliersInformation activeSubstanceList compositionType="">

<#assign activeSubstanceSummaryKey = [] />
<#assign activeSubstanceSumSupplierList = [] />
<#assign activeSubstanceSumSitesList = [] />
<#assign activeSuppliers = [] />

<#assign activeSubstanceProductKey = [] />
<#assign activeSubstanceProductSupplierList = [] />
<#assign activeSubstanceProductSitesList = [] />
  
  <#if compositionType=="summary">
  <#assign activeSubstanceSummaryKey = iuclid.getDocumentForKey(activeSubstanceList.Name)/>
  <#assign activeSubstanceSumSupplierList = iuclid.getSectionDocumentsForParentKey(activeSubstanceSummaryKey.documentKey, "FLEXIBLE_RECORD", "Suppliers") />
  <#assign activeSubstanceSumSitesList = iuclid.getSectionDocumentsForParentKey(activeSubstanceSummaryKey.documentKey, "FLEXIBLE_RECORD", "Sites") />
  
    <#assign activeSuppliers = activeSuppliers + [activeSubstanceSumSupplierList]/>


  <#elseif compositionType=="product">
  <#assign activeSubstanceProductKey = iuclid.getDocumentForKey(activeSubstanceList.Reference)/>
  <#assign activeSubstanceProductSupplierList = iuclid.getSectionDocumentsForParentKey(activeSubstanceProductKey.documentKey, "FLEXIBLE_RECORD", "Suppliers") />
  <#assign activeSubstanceProductSitesList = iuclid.getSectionDocumentsForParentKey(activeSubstanceProductKey.documentKey, "FLEXIBLE_RECORD", "Sites") />
  </#if>
</#macro>

<#macro manufacturerOfTheActiveSubstanceSection meta="" documentType="">

<#assign arrayofActiveSubstanceCompositions = [] />
<#assign root = []/>
<#assign siteKey = [] />
<#assign supplierLists = []/>
  
  <!-- check which type of composition concerned, summary or product composition -->
  <#if documentType=="compositionSummary">  
  <#assign arrayofActiveSubstanceCompositions = getActiveSubstanceSummaryComponents(mainMixtureCompositionSummaryList) />
    <#elseif documentType=="compositionProduct">
    <#assign arrayofActiveSubstanceCompositions = getActiveSubstanceComponents(mainMixtureCompositionList) />
  </#if>

  <#if arrayofActiveSubstanceCompositions?has_content>
  <#list arrayofActiveSubstanceCompositions as activeSubstances>
    <#if activeSubstances?has_content>

    <#if documentType=="compositionSummary">
    <@suppliersInformation activeSubstances "summary"/>
    <#assign root = activeSubstanceSummaryKey />
      <#elseif documentType=="compositionProduct">
        <@suppliersInformation activeSubstances "product"/>
        <#assign root = activeSubstanceProductKey />
    </#if>

    <#if activeSubstanceSumSupplierList?has_content>
      <#list activeSubstanceSumSupplierList as mySuppliers>
        <#if mySuppliers?has_content>
         <#assign supplierReferenceKey = iuclid.getDocumentForKey(mySuppliers.ManufacturerImportForm.LegalEntity)/>
         <#assign siteKey = siteKey + [supplierReferenceKey]/>
          <#if supplierReferenceKey?has_content>
            <@macroForPopulatingLegalEntity supplierReferenceKey "${tableID.table_id_6}"/> 
            <#assign part1Table1Cell1><@staticText "part_1_table1_4_cell1_table1_5_cell_2_family_table1_3_table1_4_cell1_single" /></#assign>
            <#assign part1Table1Cell2><@staticText "part_1_table1_4_cell2_table1_5_cell_3_family_table1_3_table1_4_cell1_single" /></#assign>
            <#assign part1Table1Cell3><@staticText "part_1_table1_4_cell3_table1_5_cell_4_family_table1_3_table1_4_cell1_single" /></#assign>
            <#assign part1Table1Cell4><@staticText "part_1_table1_5_cell1_family_table1_4_cell1_single" /></#assign>

            <@verticalHeaderTable supplierReferenceKey isMoreThanOneDoc(siteKey) root supplierReferenceKey "${part1Table1Cell4}" "${part1Table1Cell1}" "${part1Table1Cell2}" "${part1Table1Cell3}" "${part1Table1Cell4}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "twoColTable" "${tableID.table_id_7}"/>   
          </#if>         
        </#if>
      </#list>
    </#if>

  </#if>
  </#list>
  </#if>


</#macro>

<#macro arrayAS keys>
<#if keys.hasElement("Reference")>
<#assign activeSubstanceKey = iuclid.getDocumentForKey(keys.Reference)/>  
    <#if activeSubstanceKey?has_content && activeSubstanceKey.hasElement("ChemicalName")><@com.text activeSubstanceKey.ChemicalName/><#else></#if>
    <#if activeSubstanceKey?has_content && activeSubstanceKey.hasElement("ReferenceSubstanceName")><@com.text activeSubstanceKey.ReferenceSubstanceName/><#else></#if> 
</#if>        
</#macro>

<#macro arraySummaryAS summkeys>
<#if summkeys.hasElement("Name")>
<#assign activeSubstanceSummaryKey = iuclid.getDocumentForKey(summkeys.Name)/>
  <#if activeSubstanceSummaryKey?has_content && activeSubstanceSummaryKey.hasElement("ChemicalName")><@com.text activeSubstanceSummaryKey.ChemicalName/><#else></#if>
  <#if activeSubstanceSummaryKey?has_content && activeSubstanceSummaryKey.hasElement("ReferenceSubstanceName")><@com.text activeSubstanceSummaryKey.ReferenceSubstanceName/><#else></#if> 
</#if>
</#macro>

<#------------------------------->
<#-- Table of vertical headers -->
<#------------------------------->

<#assign part_2_section_1_1><@staticText "part_2_section_1.1(1)_family" /></#assign>

<#macro verticalHeaderTable arraykeys isMoreThanOneDoc root repeatableBlock header1="" header2="" header3="" header4="" header5="" header6="" header7="" header8="" numberOfColumns="" id="" languageCode="">

<#if isMoreThanOneDoc??>
  <#if id="Manufacturer(s) of the product" || id="Manufacturer(s) of the active substance(s)" || id="Trade name(s) of the product"> 
    <@com.emptyLine/>
  </#if>
</#if>

<#-- table configuration -->
<informaltable frame="all">
    <#if numberOfColumns=="threeColTable">
      <tgroup cols='3' colsep='1' rowsep='1' frame='all'>			
      <colspec colnum="1" colname='col1' colwidth='2.7in'/>
      <colspec colnum="2" colname='col2' colwidth='0.8in'/>
      <colspec colnum="3" colname='col3' colwidth='2.7in'/>
      <spanspec spanname='bspan' namest="col1" nameend="col2" frame='sides'></spanspec>
    <#elseif numberOfColumns=="twoColTable">
      <tgroup cols='2' colsep='1' rowsep='1' frame='all'>    
      <colspec colname='col1' />
      <colspec colname='col2' />
    </#if>
    <#-- table body -->
    <tbody>

      <#if numberOfColumns=="twoColTable" && id=="Meta SPC identifier">   
        <row>  
          <entry>${header1}</entry>
            <entry>
            <#if repeatableBlock?has_content>
              <@com.text repeatableBlock.ProductSummaryComposition.ProductFamilyGroupName/>
            </#if>
           </entry> 
        </row>
      </#if>

      <#if numberOfColumns=="twoColTable" && id=="Suffix to the authorisation number">   
        <row>  
          <entry>${header1}</entry>
            <entry>
            1-${arraykeys}
           </entry> 
        </row>  
      </#if>

       <#if numberOfColumns=="twoColTable" && id=="Product type(s)">   
        <row>  
          <entry>${header1}</entry>
            <entry>
            <#list repeatableBlock.MetaSPC.AuthorisedUses as usesMetaSPC>
              <#assign useMetaSPC = iuclid.getDocumentForKey(usesMetaSPC)/>
              <#if useMetaSPC?has_content> 
              <@macroForUseData useMetaSPC />
              ${productType}
              </#if>
            </#list>
           </entry> 
        </row>  
      </#if>


      <#if numberOfColumns=="threeColTable" && id="Meta SPC Product composition additional">       
      <#list arraykeys as array>
      <#if array?has_content>
      <#assign repeatable = array.GeneralInformation.TradeNames/>   
        <#list repeatable as tradeSequence>
          <#if tradeSequence?has_content>
            <row>
              <entry><para>${header1}</para></entry>  
              <entry><para><#if tradeSequence.TradeName?has_content><@com.text tradeSequence.TradeName /><#else></#if></para></entry>
              <entry><para><#if tradeSequence.Country?has_content><@picklistMultipleWoutSemiColon tradeSequence.Country /><#else></#if></para></entry>
            </row>
          </#if>
        </#list>
      </#if>
      </#list> 
      </#if>

	    <#if numberOfColumns=="threeColTable" && id="Authorisation holder">
        <row>
          <entry morerows="1" valign="middle">${header1}</entry>              
          <entry>${header2}</entry>              
          <entry><para><#if legalEntityNameEntry??>${legalEntityNameEntry}<#else></#if></para></entry>
        </row>
        
        <row>
            <entry>${header3}</entry>
            <entry>
              <para>
              <#if leAddress1??>${leAddress1}<#else></#if> <#if leAddress2??>${leAddress2}<#else></#if> <#if postalCode??>${postalCode}<#else></#if> <#if town??>${town}<#else></#if>
              </para>
            </entry>
        </row>

        <row>              
            <entry><para>${header4}</para></entry>
            <entry colsep='0'></entry>
            <entry><@com.text authNumber /></entry>
        </row> 

        <row>              
            <entry><emphasis>${header5}</emphasis></entry>
            <entry colsep='0'></entry>
            <entry><@com.text refAssetNumber /></entry>
        </row> 

        <row>              
            <entry >${header6}</entry>
            <entry colsep='0'></entry>
            <entry><@com.text dateOfAuth /></entry>
        </row> 

        <row>              
            <entry >${header7}</entry>
            <entry colsep='0'></entry>
            <entry><@com.text expiryDate /></entry>
        </row>      
      </#if> 
          
      <#if numberOfColumns=="twoColTable" && id="Trade name(s) of the product">
      <#if repeatableBlock?has_content> 
        <row>  
          <entry>${header1}</entry>
            <entry>
            <#if repeatableBlock?has_content>
            <#list repeatableBlock as item>
              <#if item?has_content>
                <#if item.TradeName?has_content><@com.text item.TradeName /><#else></#if>
              </#if><#if item_has_next><?linebreak?></#if>
            </#list>
            <#else></#if>
            </entry> 
        </row> 
      </#if>        
      </#if>

      <#if numberOfColumns=="twoColTable" && id="Formulation types summary" || id=="Formulation types meta spc">
        <row>  
          <entry>${header1}</entry>
            <entry>
            <#if id="Formulation types summary">
            <@formulationTypes mainMixtureCompositionSummaryList "${id}" />
            <#elseif id=="Formulation types meta spc">
            <@formulationTypes arraykeys "${id}" />
            </#if>
            </entry> 
        </row>     
      </#if>
        
      <#if numberOfColumns=="twoColTable" && id="Family name">
        <#if _subject.MixtureName?has_content> 
          <row>  
            <entry>${header1}</entry>
              <entry>
              <@com.text _subject.MixtureName />
              </entry> 
          </row> 
        </#if>        
      </#if>

      <#if numberOfColumns=="twoColTable" && id="Product type">      
        <row>  
            <entry>${header1}</entry>
            <entry>  

            <#assign phrases = productTypeFunction(usesList)/>
              <#list phrases as phrase>
                  <para>${phrase}</para>
              </#list>
    
            </entry> 
        </row>
      </#if>      
      
      <#if numberOfColumns=="twoColTable" && id="Meta SPC Hazard and precautionary statements">   
           
        <row>
          <entry>${header1}</entry>    
          <entry>          
          <#if hazard?has_content>${hazard}</#if>
          <#if supplementalGHShazards?has_content>${supplementalGHShazards}</#if>
          <#if additionalLabels?has_content>${additionalLabels}</#if>          
          </entry>
        </row>
        <row>
          <entry>${header2} </entry>    
          <entry>
          <#if precautionary?has_content>${precautionary}</#if>
          </entry>
        </row>  
      </#if>

      <#if numberOfColumns=="twoColTable" && id="Hazard and precautionary statements">          
        <row>
          <entry>${header1}</entry>    
          <entry>
            <#if hazard?has_content>${hazard}</#if>
          </entry>
        </row>
        <row>
          <entry>${header2} </entry>    
          <entry>
            <#if precautionary?has_content>${precautionary}</#if>
          </entry>
        </row>      
      </#if>

      <#if numberOfColumns=="twoColTable">

        <#if id="Manufacturer(s) of the product" || id="Manufacturer(s) of the active substance(s)">
                  
            <#if id="Manufacturer(s) of the active substance(s)">
            <row>
              <entry>${header1}</entry>    
              <entry> 
                <@com.text root.ChemicalName />             
              </entry>
            </row>
            </#if>

            <row>
              <entry>${header2}</entry>    
              <entry>       
                <#if legalEntityNameEntry??><@com.text legalEntityNameEntry /><#else></#if>
              </entry>
            </row>
            <row>
              <entry>${header3}</entry>    
              <entry>
                <#if leAddress1??><@com.text leAddress1/><#else></#if> <#if leAddress2??><@com.text leAddress2/><#else></#if> <#if postalCode??><@com.text postalCode/><#else></#if> <#if town??><@com.text town /><#else></#if>
              </entry>
            </row>

            <row>
              <entry>${header4}</entry>                
                <#if id="Manufacturer(s) of the product" || id="Manufacturer(s) of the active substance(s)">                 
                    <entry>
                        <#if repeatableBlock?has_content>
                        <#assign supplier = getSitesBelongingToSupplier(sitesList, repeatableBlock.documentKey.uuid) />
                          <#if supplier?has_content>
                            <#list supplier as mysupp>             
                              <para><@com.text mysupp.name/></para>
                            </#list>             
                          </#if>
                        </#if>
                    </entry> 
                </#if>
            </row>
        </#if>
      </#if>
    </tbody>
    </tgroup>
  </informaltable>
</#macro>

<#function productTypeFunction usesList>

    <#assign localisedTexts = [] />
    <#assign locale = [] />
    <#assign locale = "en" />

    <#list usesList as uses>
        <#if uses?has_content>
            <#list uses.IntendedUsesAndExposure.ProductType as myProdType>
                <#if myProdType?has_content>
                    <#assign localizPhrase = iuclid.localizedPhraseDefinitionFor(myProdType.code locale)/>
                    <#assign localisedTexts = localisedTexts + [localizPhrase.text]/>
                </#if>
            </#list>
        </#if>
    </#list>

    <#local uniqueTexts = []/>
    <#list localisedTexts as item>
        <#if !(uniqueTexts?seq_contains(item))>
            <#local uniqueTexts = uniqueTexts + [item]/>
        </#if>
    </#list>
    <#return uniqueTexts/>

</#function>

<#-- headers which are horiztonally placed -->
<#macro horizontalHeaderTable arrayKeys isMoreThanOneDoc rootMixture repeatableBlock header1="" header2="" header3="" header4="" header5="" header6="" numberOfColumns="" id="">

	<informaltable frame="all">			

      <tgroup cols='6'>
				<colspec width="16.6%" />
				<colspec width="16.6%" />
        <colspec width="16.6%" />
        <colspec width="16.6%" />
        <colspec width="16.6%" />
        <colspec width="16.6%" />

				<tbody>

          <row>          
              <entry>${header1}</entry>
              <entry>${header2}</entry>
              <entry>${header3}</entry>
              <entry>${header4}</entry> 
              <entry>${header5}</entry>
              <entry>${header6}</entry>           
          </row> 
    
            <#-- iterate through repeatable block of components -->
            <#if arrayKeys?has_content>
              <#list arrayKeys as item>  
              <#if item?has_content> 
                <#-- get the component key -->
                <#if id=="Qualitative and quantitative information on the composition of the product" || id=="Meta SPC Product composition">                
                <#local componentKey = iuclid.getDocumentForKey(item.Reference)/>

                <#elseif id=="Qualitative and quantitative information on the composition of the family summary" || id=="Qualitative and quantitative information on the composition of the meta spc">
                <#local componentKey = iuclid.getDocumentForKey(item.Name)/>
                </#if>

                    <#if componentKey?has_content>
                    <#-- macro to capture all values to identify the mixture's  components -->
                    <@substanceAndReferenceSubstanceIdentifiers componentKey item "${id}"/>
                      <#-- populate row if the component is a SUBSTANCE -->
                      <#if isSubstanceComponent(componentKey)>
                        <row>  
                        <entry><#if componentKey.ChemicalName?has_content><@com.text componentKey.ChemicalName/><#else></#if></entry>
                        <entry><#if iupacSubstance?has_content>${iupacSubstance}<#else></#if></entry>
                        <entry><#if functionValue?has_content>${functionValue}<#else></#if></entry>    
                        <entry><#if casNumberSubstance?has_content>${casNumberSubstance}<#else></#if></entry>    
                        <entry><#if ecNumberSubstance?has_content>${ecNumberSubstance}<#else></#if></entry>    
                        <entry><#if concentrationLower?has_content>${concentrationLower}<#elseif concentrationRange?has_content>${concentrationRange}<#else></#if></entry>     
                        </row>
                      <#-- populate row if the component is a REFERENCE_SUBSTANCE -->
                      <#elseif !isSubstanceComponent(componentKey)>
                        <row>  
                        <entry><#if componentKey.ReferenceSubstanceName?has_content><@com.text componentKey.ReferenceSubstanceName/><#else></#if></entry>
                        <entry><#if iupacReferenceSubstance?has_content>${iupacReferenceSubstance}<#else></#if></entry>
                        <entry><#if functionValue?has_content>${functionValue}<#else></#if></entry>    
                        <entry><#if casNumberReferenceSubstance?has_content>${casNumberReferenceSubstance}<#else></#if></entry>    
                        <entry><#if ecNumberReferenceSubstance?has_content>${ecNumberReferenceSubstance}<#else></#if></entry>    
                        <entry><#if concentrationLower?has_content>${concentrationLower}<#elseif concentrationRange?has_content>${concentrationRange}<#else></#if></entry>     
                        </row>
                      </#if>
                    </#if>
                  </#if>

              </#list>
            </#if>

        </tbody>
			</tgroup>
  </informaltable>  
</#macro>

<#-- formal table for uses -->
<#macro useDescription isMoreThanOneDoc useMetaSPC indexcounter="" header1="" header2="" header3="" header4="" header5="" header6="" header7="" header8="">

<#if isMoreThanOneDoc??>
  <@com.emptyLine/>
</#if>

<table border="1">
    	
    <title>${useName}</title>
    <col width="40%" />
    <col width="60%" />	

    <tbody>
				<tr>        							
					<th>${header1}</th>
					<th> 
            ${productType}
          </th>
				</tr>

        <#if authorisedUseDescription?has_content>
          <tr>
            <td>${header2}</td>
            <td><#if authorisedUseDescription??>${authorisedUseDescription}</#if></td>
          </tr>
        </#if>

        <#if targetOrganism?has_content>
        <tr>
          <td>${header3}</td>
          <td><#if targetOrganism??>${targetOrganism}</#if></td>
        </tr>
        </#if>
        
        <#if fieldsOfUseDescription?has_content>
          <tr>
            <td>${header4}</td>
            <td>
            <#if fieldsOfUse??>${fieldsOfUse}</#if>
            <@com.emptyLine />
            <#if fieldsOfUseDescription??>${fieldsOfUseDescription}</#if>
            </td>
          </tr>
        </#if>

        <#if applicationMethods?has_content>
        <tr>
          <td>${header5}</td>
          <td>${applicationMethods}</td>
        </tr>
        </#if>

        <#if applicationRates?has_content>
        <tr>
          <td>${header6}</td>
          <td><#if applicationRates??>${applicationRates}</#if></td>
        </tr>
        </#if>

        <#if categoriesOfUsers?has_content>
        <tr>
          <td>${header7}</td>
          <td><#if categoriesOfUsers??>${categoriesOfUsers}</#if></td>
        </tr>
        </#if>

        <#if packagingSizeAndMaterial?has_content>
        <tr>
          <td>${header8}</td>
          <td><#if packagingSizeAndMaterial??>${packagingSizeAndMaterial}</#if></td>
        </tr>
        </#if>

    </tbody>
</table>
</#macro>


<#---------------------------------------->
<#-- Functions to condition data output -->
<#---------------------------------------->

<#-- Only return if more than 1 doc in sequence -->
<#function isMoreThanOneDoc sectionDoc>
<#if sectionDoc?has_content && sectionDoc?size gt 0>
  <#return true>
  <#else>
    <#return false/>
</#if>
  <#return false/>
</#function>



<#------------------------------->
<#-- Functions providing array -->
<#------------------------------->

<#macro macroForListingUses usesList>

  <#assign uses = [] />

  <#if usesList?has_content>
  <#list usesList as use>
    <#if use?has_content>
      <#assign uses = uses + [use] />
    </#if>
  </#list>
  </#if>
  
</#macro>


<#------------------------------------------------------>
<#-- Functions providing data for sections and tables -->
<#------------------------------------------------------>

<#macro formulationTypes mainMixtureCompositionSummaryList id="">
<#if mainMixtureCompositionSummaryList?has_content>

  <#if id="Formulation types summary">
  <#list mainMixtureCompositionSummaryList as composition>
      <#if isFamilyComposition(composition) && composition.ProductSummaryComposition.FormulationType?has_content> 
        <@picklistMultipleWoutSemiColon composition.ProductSummaryComposition.FormulationType/>
      </#if>
  </#list>
  <#elseif id="Formulation types meta spc">      
      <#if mainMixtureCompositionSummaryList.ProductSummaryComposition.FormulationType?has_content>
        <@picklistMultipleWoutSemiColon mainMixtureCompositionSummaryList.ProductSummaryComposition.FormulationType/>
      </#if>
  </#if>
</#if> 
</#macro>

<#macro macroForUseData use>

<#assign productType = [] />
<#assign useName = [] />
<#assign authorisedUseDescription = [] />
<#assign targetOrganism = [] />
<#assign fieldsOfUse = [] />
<#assign fieldsOfUseDescription = [] />
<#assign applicationMethods = [] />
<#assign applicationRates = [] />
<#assign categoriesOfUsers = [] />
<#assign packagingSizeAndMaterial = [] />
<#assign directionsForUse = [] />

    <#-- Table title with index counter -->
    <#assign useName>
      <#if use.IntendedUsesAndExposure.UseName?has_content>
        <@com.text use.IntendedUsesAndExposure.UseName />
        <#else>
        <@com.text use.name />
      </#if>
    </#assign>

    <#-- "Product type" data -->
    <#assign productType><@picklistMultipleWoutSemiColon use.IntendedUsesAndExposure.ProductType/></#assign>

    <#-- "Where relevant, an exact description of the authorised use" data -->
    <#assign authorisedUseDescription>
      <#if use.IntendedUsesAndExposure.DetailedDescription?has_content>
        <@iuclid.label for=use.IntendedUsesAndExposure.DetailedDescription var="fieldLabel"/>
          <@com.richText use.IntendedUsesAndExposure.DetailedDescription/>
          <#else> 
      </#if>
    </#assign>

    <#-- "Target organism(s) (including development stage)" data -->
    <#assign targetOrganism>
    <#if use.IntendedUsesAndExposure.TargetOrganisms?has_content>
    <#assign targetOrganismsList = iuclid.getDocumentForKey(use.IntendedUsesAndExposure.TargetOrganisms)/>
    <#list targetOrganismsList.GeneralInformation.PestTargetOrganismsToBeControlled.TargetOrganisms as targetOrganisms>
      <#if targetOrganisms?has_content>

        <@iuclid.label for=targetOrganisms.ScientificName var="sciNameLabel"/>
        <@iuclid.label for=targetOrganisms.CommonName var="commonNameLabel"/>
        <@iuclid.label for=targetOrganisms.DevelopmentalStage var="devStageLabel"/>

          <#if targetOrganisms.ScientificName?has_content>
          <para>${sciNameLabel}: <@com.picklist targetOrganisms.ScientificName /></para>
          </#if>

          <#if targetOrganisms.CommonName?has_content>
          <para>${commonNameLabel}: <@com.picklist targetOrganisms.CommonName /></para>
          </#if>

          <#if targetOrganisms.DevelopmentalStage?has_content>
           <para>${devStageLabel?replace('of target pest','')?trim}: <@com.picklist targetOrganisms.DevelopmentalStage /></para>
          </#if>

      </#if><#if targetOrganisms_has_next><@com.emptyLine /></#if>
    </#list>
    </#if>
    </#assign>

    <#-- "Field(s) of use" data -->
    <#assign fieldsOfUse>
      <@picklistMultipleWoutSemiColon use.IntendedUsesAndExposure.FieldOfUse/>
    </#assign>

    <#-- "Field of use description" data -->
    <#assign fieldsOfUseDescription>
      <@com.text use.IntendedUsesAndExposure.FieldOfUseDescription/>
    </#assign>
  
    <#-- "Application method(s)" data -->
    <#assign applicationMethods>  

      <#if use.IntendedUsesAndExposure.ApplicationMethods?has_content>
      <#list use.IntendedUsesAndExposure.ApplicationMethods as applications>
        <#if applications?has_content>
        <#local applicationMethod = iuclid.getDocumentForKey(applications)/>
        <#if applicationMethod?has_content>
          
          <@iuclid.label for=applicationMethod.DirectionsForUse.MethodOfApplication var="appMethodLabel"/>
          <@iuclid.label for=applicationMethod.DirectionsForUse.DetailedDescriptionOfMethod var="detailedDesLabel"/> 
          <@iuclid.label for=applicationMethod.DirectionsForUse.NumberAndTimingOfApplications var="numberAndTimings"/> 
          
          <#if applicationMethod.DirectionsForUse.MethodOfApplication?has_content || applicationMethod.DirectionsForUse.DetailedDescriptionOfMethod?has_content>
            <para>
              ${appMethodLabel}: <@com.picklistMultiple applicationMethod.DirectionsForUse.MethodOfApplication />
            </para>
              <@com.emptyLine />
            <para>
              ${detailedDesLabel}:             
              <para><@com.text applicationMethod.DirectionsForUse.DetailedDescriptionOfMethod /></para>
            </para>
          </#if>          
      </#if>
      </#if>
    </#list>
    </#if>
    </#assign>

    <#-- "Application rate(s) and frequency" data -->
    <#assign applicationRates>
      
      <#if use.IntendedUsesAndExposure.ApplicationMethods?has_content>
      <#list use.IntendedUsesAndExposure.ApplicationMethods as applications>
        <#if applications?has_content>
        <#local applicationMethod = iuclid.getDocumentForKey(applications)/>
        <#if applicationMethod?has_content>
          
          <@iuclid.label for=applicationMethod.DirectionsForUse.MethodOfApplication var="appMethodLabel"/>
          <@iuclid.label for=applicationMethod.DirectionsForUse.DetailedDescriptionOfMethod var="detailedDesLabel"/> 
          <@iuclid.label for=applicationMethod.DirectionsForUse.NumberAndTimingOfApplications var="numberAndTimings"/>

          <#if applicationMethod.DirectionsForUse.ApplicationDoseFinalConcentration?has_content>
          <#list applicationMethod.DirectionsForUse.ApplicationDoseFinalConcentration as concentrations>

            <para>Application Rate: 
              <#if concentrations.ApplicationDose?has_content && concentrations.hasElement("ApplicationDose")>
                <@com.range concentrations.ApplicationDose />
              <#elseif concentrations.Remarks?has_content>          
                <@com.text concentrations.Remarks />
              </#if>
            </para>
            <@com.emptyLine />
            <para>Dilution %       
              <#if concentrations.Dilution?has_content>
                <@com.number concentrations.Dilution />
              </#if> 

              <#if concentrations.DilutionRemarks?has_content>
                <@com.text concentrations.DilutionRemarks />
              </#if>
            </para>

          </#list>
          </#if>

          <#if applicationMethod.DirectionsForUse.NumberAndTimingOfApplications?has_content>
            <@com.emptyLine />
              <para>
                ${numberAndTimings}:
                <@com.richText applicationMethod.DirectionsForUse.NumberAndTimingOfApplications />
              </para>
          </#if>          
         
          
        </#if>
        </#if>
      </#list>
      </#if>
    </#assign>

    <#-- "Category(ies) of users" data -->
    <#assign categoriesOfUsers>
      <@com.picklistMultiple use.IntendedUsesAndExposure.User />
    </#assign>

    <#-- "Pack sizes and packaging material" data -->
    <#assign packagingSizeAndMaterial>
    <#if use.IntendedUsesAndExposure.Packagings?has_content>
      <#list use.IntendedUsesAndExposure.Packagings as packagings>
        <#if packagings?has_content>
        <#local packaging = iuclid.getDocumentForKey(packagings)/>
        <#if packaging?has_content>
          <@com.richText packaging.Packaging.AdditionalInfo />
        </#if>
        </#if>
      </#list>
    </#if>
    </#assign>

    <#if use.IntendedUsesAndExposure.InstructionsForUseAndMeasuresToProtect?has_content && use.hasElement("IntendedUsesAndExposure.InstructionsForUseAndMeasuresToProtect")>
     <#assign directionsForUse = iuclid.getDocumentForKey(use.IntendedUsesAndExposure.InstructionsForUseAndMeasuresToProtect)/>
     <#else>          
    </#if>

</#macro>

 <#macro directionsForUseReferencedByAuthorisedUses useMetaSPC id="">

 <#if id=="Meta SPC Use description" || id=="Use description">

  <!-- 4.1.1 Use-specific instructions for use -->
  <section><title role="HEAD-4"><@staticText "part_2_section_4.1.1_family_section_4.1.1_single" /></title><@com.emptyLine/>  
  <@macroForUseData useMetaSPC />
  
  <#if directionsForUse?has_content && directionsForUse.UseSpecificInstructionsForUse?has_content>
  <@com.value directionsForUse.UseSpecificInstructionsForUse />
  <#else>
  </#if>

  </section>
  
  <!-- 4.1.2 Use-specific risk mitigation measures -->
  <section><title role="HEAD-4"><@staticText "part_2_section_4.1.2_family_section_4.1.2_single" /></title><@com.emptyLine/>

  <#if directionsForUse?has_content && directionsForUse.UseSpecificRiskMitigationMeasures?has_content>
  <@com.richText directionsForUse.UseSpecificRiskMitigationMeasures />
  <#else></#if>

  </section>

  <!-- 4.1.3 Where specific to the use, the particulars of likely direct or indirect effects, first aid instructions and emergency measures to protect the environment -->
  <section><title role="HEAD-4"><@staticText "part_2_section_4.1.3_family_section_4.1.3_single" /></title><@com.emptyLine/>

  <#if directionsForUse?has_content && directionsForUse.SpecificToTheUseTheParticularsOfLikelyDirectOrIndirectEffects?has_content>
  <@com.richText directionsForUse.SpecificToTheUseTheParticularsOfLikelyDirectOrIndirectEffects />
  <#else></#if>    

  </section>

  <!-- 4.1.4 Where specific to the use, the instructions for safe disposal of the product and its packaging -->
  <section><title role="HEAD-4"><@staticText "part_2_section_4.1.4_family_section_4.1.4_single" /></title><@com.emptyLine/>
  <#if directionsForUse?has_content && directionsForUse.WhereSpecificToTheUseTheInstructionsForSafeDisposalOfTheProductAndItsPackaging?has_content>
  <@com.richText directionsForUse.WhereSpecificToTheUseTheInstructionsForSafeDisposalOfTheProductAndItsPackaging />
  <#else></#if>
  
  </section>

  <!-- 4.1.5 Where specific to the use, the conditions of storage and shelf-life of the product under normal conditions of storage -->
  <section><title role="HEAD-4"><@staticText "part_2_section_4.1.5_family_section_4.1.5_single" /></title>

  <#if directionsForUse?has_content && directionsForUse.SpecificToTheUseTheConditionsOfStorageAndShelfLifeOfTheProduct?has_content>
  <@com.richText directionsForUse.SpecificToTheUseTheConditionsOfStorageAndShelfLifeOfTheProduct />
  <#else></#if>

  </section>

</#if>

</#macro>

<#macro directionsForUseForMetaSPC generalDirectionsForUseMetaSPC id="">
<!-- 5.1 Instructions for use -->
<section><title role="HEAD-4"><@staticText "part_2_section_5.1_family_part_2_section_5.1_single" /></title>
<#if id=="Meta SPC Use description">
  <#if generalDirectionsForUseMetaSPC?has_content>
  <@com.richText generalDirectionsForUseMetaSPC.InstructionsForUse.InstructionsForUse /><#else>
  </#if> 
<#else>
  <#if protectionMeasuresNotLinkedToUses?has_content>
  <#list protectionMeasuresNotLinkedToUses as proMeasures>
    <#if proMeasures?has_content>
    <@com.richText proMeasures.InstructionsForUse.InstructionsForUse /><#else>
    </#if>  
  </#list>
  </#if>
</#if>
</section>

<!-- 5.2 Risk mitigation measures -->
<section><title role="HEAD-4"><@staticText "part_2_section_5.2_family_part_2_section_5.2_single" /></title>
<#if id=="Meta SPC Use description">
  <#if generalDirectionsForUseMetaSPC?has_content>
  <@com.richText generalDirectionsForUseMetaSPC.MeasuresToProtect.ControlMeasuresOfRepellents /><#else>
  </#if> 
<#else>
  <#if protectionMeasuresNotLinkedToUses?has_content>
  <#list protectionMeasuresNotLinkedToUses as proMeasures>
    <#if proMeasures?has_content>
      <@com.richText proMeasures.MeasuresToProtect.ControlMeasuresOfRepellents /><#else>
    </#if>
  </#list>  
  </#if>
</#if>
</section>

<!-- 5.3 Particulars of likely direct or indirect effects, first aid instructions and emergency measures to protect the environment -->
<section><title role="HEAD-4"><@staticText "part_2_section_5.3_family_part_2_section_5.3_single" /></title>
<#if id=="Meta SPC Use description">
  <#if generalDirectionsForUseMetaSPC?has_content>
  <@com.richText generalDirectionsForUseMetaSPC.MeasuresToProtect.ParticularsOfLikelyDirect /><#else>
  </#if>
<#else>
  <#if protectionMeasuresNotLinkedToUses?has_content>
  <#list protectionMeasuresNotLinkedToUses as proMeasures>
    <#if proMeasures?has_content>
      <@com.richText proMeasures.MeasuresToProtect.ParticularsOfLikelyDirect /><#else>
    </#if>
  </#list> 
  </#if>
</#if>
</section>

<!-- 5.4 Instructions for safe disposal of the product and its packaging -->
<section><title role="HEAD-4"><@staticText "part_2_section_5.4_family_part_2_section_5.4_single" /></title>
<#if id=="Meta SPC Use description">
  <#if generalDirectionsForUseMetaSPC?has_content>
  <@com.richText generalDirectionsForUseMetaSPC.ProceduresForWasteManagement.InstructionsForSafeDisposal /><#else>
  </#if>
<#else>
  <#if protectionMeasuresNotLinkedToUses?has_content>
  <#list protectionMeasuresNotLinkedToUses as proMeasures>
    <#if proMeasures?has_content>
      <@com.richText proMeasures.ProceduresForWasteManagement.InstructionsForSafeDisposal /><#else>
    </#if>
  </#list>
  </#if>
</#if>
</section>

<!-- 5.5 Conditions of storage and shelf-life of the product under normal conditions of storage -->
<section><title role="HEAD-4"><@staticText "part_2_section_5.5_family_part_2_section_5.5_single" /></title>
<#if id=="Meta SPC Use description">
  <#if generalDirectionsForUseMetaSPC?has_content>
  <@com.richText generalDirectionsForUseMetaSPC.MeasuresToProtect.RecommendedMethodsAndPrecautionsConcerningStorage /><#else>
  </#if>
<#else>
  <#if protectionMeasuresNotLinkedToUses?has_content>
  <#list protectionMeasuresNotLinkedToUses as proMeasures>
    <#if proMeasures?has_content>
      <@com.richText proMeasures.MeasuresToProtect.RecommendedMethodsAndPrecautionsConcerningStorage /><#else>
    </#if>
  </#list>
  </#if>
</#if>
</section>

</#macro>

<#macro otherInformation summaryAndEvaluationList id="">
<#if id=="Meta SPC Other information">

    <#if summaryAndEvaluationList?has_content>
        <@com.richText summaryAndEvaluationList.OtherInformation.OtherInformation /><#else>
    </#if>

<#else>

    <#if summaryAndEvaluationList?has_content>
      <#list summaryAndEvaluationList as otherInformation>
      <#if otherInformation?has_content>
        <@com.richText otherInformation.OtherInformation.OtherInformation /><#else>
      </#if>
      </#list>
    </#if>     
</#if>
</#macro>

<#macro macroForPopulatingLegalEntity legal id="">
<#if legal?has_content>
  <#assign legalEntityuuid>
      <#if legal.documentKey.uuid?has_content>${legal.documentKey.uuid}<#else>dummystring</#if>
  </#assign>
  <#assign legalEntityNameEntry>   
      <#if legal.GeneralInfo.LegalEntityName?has_content><@com.text legal.GeneralInfo.LegalEntityName/></#if>
  </#assign>
  <#assign leAddress1>
      <#if legal.GeneralInfo.ContactAddress.Address1?has_content><@com.text legal.GeneralInfo.ContactAddress.Address1/></#if>
  </#assign>
  <#assign leAddress2>
      <#if legal.GeneralInfo.ContactAddress.Address2?has_content><@com.text legal.GeneralInfo.ContactAddress.Address2/></#if>
  </#assign>
  <#assign postalCode>
      <#if legal.GeneralInfo.ContactAddress.Postal?has_content><@com.text legal.GeneralInfo.ContactAddress.Postal/></#if>
  </#assign>
  <#assign town>
      <#if legal.GeneralInfo.ContactAddress.Town?has_content><@com.text legal.GeneralInfo.ContactAddress.Town/></#if>
  </#assign>
</#if>
</#macro>

<#macro macroForPopulatingSite legal id="">
<#if legal?has_content>
  <#assign siteuuid>
      <#if legal.documentKey.uuid?has_content>${legal.documentKey.uuid}<#else>dummystring</#if>
  </#assign>
  <#assign siteEntityNameEntry>   
      <#if legal.GeneralInfo.SiteName?has_content><@com.text legal.GeneralInfo.SiteName/></#if>
  </#assign>
</#if>
</#macro>

<#macro substanceAndReferenceSubstanceIdentifiers componentKey item id="">

    <#-- substance component -->
    <#if isSubstanceComponent(componentKey)>
      <#if componentKey?has_content>
        <#assign referenceSubstance = iuclid.getDocumentForKey(componentKey.ReferenceSubstance.ReferenceSubstance)/>
        <#if referenceSubstance?has_content>
          <#-- EC Number -->
          <#assign ecNumberSubstance><@com.inventoryECNumber com.getReferenceSubstanceKey(componentKey.ReferenceSubstance.ReferenceSubstance) /></#assign>
          <#-- CAS Number -->
          <#assign casNumberSubstance><#if referenceSubstance.Inventory.CASNumber?has_content><@com.text referenceSubstance.Inventory.CASNumber/></#if></#assign>
            <#-- IUPAC Number -->
          <#assign iupacSubstance><#if referenceSubstance.IupacName?has_content><@com.text referenceSubstance.IupacName/></#if></#assign>         
        </#if>       
      </#if>
    </#if>

    <#-- reference substance component -->
    <#if !isSubstanceComponent(componentKey)>
      <#if componentKey?has_content>
        <#-- IUPAC Number -->
        <#assign iupacReferenceSubstance><#if componentKey.IupacName?has_content><@com.text componentKey.IupacName/></#if></#assign>
        <#-- CAS Number -->
        <#assign casNumberReferenceSubstance><#if componentKey.Inventory.CASNumber?has_content><@com.text componentKey.Inventory.CASNumber/></#if></#assign>
        <#-- EC Number -->
        <#if id=="Qualitative and quantitative information on the composition of the product" || id=="Meta SPC Product composition">                
          <#assign ecNumberReferenceSubstance><@com.inventoryECNumber com.getReferenceSubstanceKey(item.Reference) /></#assign> 
        <#elseif id=="Qualitative and quantitative information on the composition of the family summary" || id="Qualitative and quantitative information on the composition of the meta spc">
          <#assign ecNumberReferenceSubstance><@com.inventoryECNumber com.getReferenceSubstanceKey(item.Name) /></#assign> 
        </#if>
      </#if>
    </#if>
    
    <#-- Function of component -->
    <#assign functionValue>
      <#if item.Function?has_content>
        <#assign function = item.Function />

        <#if com.picklistValueMatchesPhrases(function, ["active substance"])>
          <@com.value function/>

        <#elseif com.picklistValueMatchesPhrases(function, ["releaser"])>
          <@com.value function />

        <#elseif !(com.picklistValueMatchesPhrases(function, ["active substance", "releaser"]))>
          <#assign part_1_part_2_table2_1_table7_cell3_value_nonActiveSubstance_family_table2_1_cell3_value_nonActiveSubstance_single><@spcUtils.staticText "part_1_part_2_table2_1_table7_cell3_value_nonActiveSubstance_family_table2_1_cell3_value_nonActiveSubstance_single"/></#assign>
          <para>${part_1_part_2_table2_1_table7_cell3_value_nonActiveSubstance_family_table2_1_cell3_value_nonActiveSubstance_single}</para>
        </#if>

      </#if>
    </#assign>

    <#-- Content % of component for product -->
    <#assign concentrationLower>
    <#if id=="Qualitative and quantitative information on the composition of the product" || id=="Meta SPC Product composition" && item.TypicalConcentration?has_content>
      <#assign concentration = item.TypicalConcentration />
      <#if concentration.lower.value?has_content><@com.number concentration.lower.value/></#if>
    </#if>
    </#assign>
    
    <#-- Content % of component for summary -->
    <#assign concentrationRange>
    <#if id=="Qualitative and quantitative information on the composition of the family summary" || id="Qualitative and quantitative information on the composition of the meta spc" && item.Concentration?has_content>
      <@com.range item.Concentration />
    </#if>
    </#assign>
</#macro>

<#macro macroForPopulatingGhsLabelling array id="">

<#assign hazard = [] />
<#assign precautionary = [] />
<#assign supplementalGHShazards = [] />
<#assign additionalLabels = [] />
<#assign ghs = [] />

<#if id="Meta SPC Hazard and precautionary statements">
    <#if array.MetaSPC.ClassificationAndLabelling?has_content>

      <#assign ghs = iuclid.getDocumentForKey(array.MetaSPC.ClassificationAndLabelling)/>
      <#-- standard hazard labelling -->
      <#assign hazardStatementList = ghs.Labelling.HazardStatementsBlock.HazardStatements />	
      <#if hazardStatementList?has_content>
        <#assign hazard><@keyClassifcationAndLabellingInformation.HazardStatementList hazardStatementList/></#assign>
      </#if>

      <#-- standard precuationary statement labelling -->
      <#assign precautionaryStatementList = ghs.Labelling.PrecautionaryStatementsBlock.PrecautionaryStatements />	
      <#if precautionaryStatementList?has_content>
        <#assign precautionary><@keyClassifcationAndLabellingInformation.PrecautionaryStatementsList precautionaryStatementList/></#assign>
      </#if>

      <#-- supplemental GHS hazard labelling -->  
      <#if !(ghs.Labelling.LabelingRequirementsBlock.LabelingRequirements?has_content)>
      <#else>    
        <para>
          <#assign supplementalGHShazards><@keyClassifcationAndLabellingInformation.SupplimentalHazardStatementList ghs.Labelling.LabelingRequirementsBlock.LabelingRequirements/> </#assign>
        </para>     
      </#if>  

      <#-- additional labelling generic -->    
      <#if !(ghs.Labelling.LabelingRequirementsBlock.AdditionalLabelling?has_content)>
      <#else>		      
        <para>
          <emphasis role="underline">Additional labelling:</emphasis>
          <#assign additionalLabels> <@keyClassifcationAndLabellingInformation.AdditionalLabellingList ghs.Labelling.LabelingRequirementsBlock.AdditionalLabelling/></#assign>
        </para>      
      </#if>
    </#if>
  
<#elseif id="Hazard and precautionary statements">

    <#list ghsList as ghs>
      <#if ghs?has_content>

          <#assign hazardStatementList = ghs.Labelling.HazardStatementsBlock.HazardStatements />	
          <#if hazardStatementList?has_content>
            <#assign hazard><@keyClassifcationAndLabellingInformation.HazardStatementList hazardStatementList/></#assign>
          </#if>

        <#assign precautionaryStatementList = ghs.Labelling.PrecautionaryStatementsBlock.PrecautionaryStatements />	
          <#if precautionaryStatementList?has_content>              
              <#assign precautionary><@keyClassifcationAndLabellingInformation.PrecautionaryStatementsList precautionaryStatementList/></#assign>
          </#if>
      </#if>
    </#list>

  </#if>
</#macro>


<#macro siteInformation location>

<#if location?has_content>
  <#list location as locale>
    <#if locale?has_content>
      <#local linkedSite = iuclid.getDocumentForKey(locale.ReferenceSite)/>
      <#if linkedSite?has_content>
        <@com.text linkedSite.GeneralInfo.SiteName /><#if locale_has_next>; </#if>
      </#if>
    </#if>
  </#list>
</#if>
</#macro>



<#---------------->
<#-- Functions  -->
<#---------------->

<#-- get the active substance components for only *SUBSTANCE and *REFERENCE_SUBSTANCE -->
<#function getActiveSubstanceComponents mainMixtureCompositionList>
<#local activeSubstanceComponents = [] />

<#if !(mainMixtureCompositionList?has_content)>
  <#return [] />
</#if>

<#list mainMixtureCompositionList as composition>
  <#if composition?has_content>
 
    <#local componentList = composition.Components.Components/>
    
    <#list componentList as component>
      <#if component?has_content>
        <#if isSubstanceOrReferenceSubstance(component, "componentProduct")>
        <#if isComponentActiveSubstance(component)>
          <#local activeSubstanceComponents = activeSubstanceComponents + [component]/>
        </#if>
        </#if>
      </#if>			
    </#list>
  </#if>
</#list>

	<#return activeSubstanceComponents/>
</#function>


<#-- get the active substance components from product summary for only *SUBSTANCE and *REFERENCE_SUBSTANCE -->
<#function getActiveSubstanceSummaryComponents mainMixtureCompositionSummaryList>
<#assign activeSubstanceSummaryComponents = [] />

<#if !(mainMixtureCompositionSummaryList?has_content)>
  <#return [] />
</#if>

<#list mainMixtureCompositionSummaryList as summaryComposition>
 
 <#if summaryComposition?has_content>
 
    <#list summaryComposition.ProductSummaryComposition.Composition as component>
    
      <#if component?has_content>
        <#if isSubstanceOrReferenceSubstance(component, "componentSummary")>
        <#if isComponentActiveSubstance(component)>
          <#assign activeSubstanceSummaryComponents = activeSubstanceSummaryComponents + [component]/>
          
        </#if>
        </#if>
        
      </#if>
      		
    </#list>
  </#if>
  <#return activeSubstanceSummaryComponents/>
</#list>
	
</#function>

<#-- get a list of summary compositions -->
<#function getSummaryCompositions mainMixtureCompositionSummaryList summaryType="">
<#local summaryCompositionsList = [] />

<#if !(mainMixtureCompositionSummaryList?has_content)>
  <#return [] />
</#if>

<#list mainMixtureCompositionSummaryList as compositions>
 
  <#if compositions?has_content>
    
      <#if isMetaSPCcomposition(compositions) && summaryType=="metaspc"> 
      <#local summaryCompositionsList = summaryCompositionsList + [compositions]/>
      </#if>

  </#if>
</#list>
	<#return summaryCompositionsList/>
</#function>

<#-- check if function is Active Substance -->
<#function isComponentActiveSubstance component>
	<#return component.Function?has_content && com.picklistValueMatchesPhrases(component.Function, ["active substance"]) />
</#function>

<#-- check if summary is a family composition -->
<#function isFamilyComposition compositionFamilySummaries>
<#assign metaSPC = compositionFamilySummaries.ProductSummaryComposition.RepresentsMetaSPC />
<#if !metaSPC>
  <#return true>
    <#else>
    <#return false>
</#if>
    <#return false/>
</#function>

<#-- check if summary is a meta spc composition -->
<#function isMetaSPCcomposition compositionFamilySummaries>
<#assign metaSPC = compositionFamilySummaries.ProductSummaryComposition.RepresentsMetaSPC />
<#if metaSPC>
  <#return true>
    <#else>
    <#return false>
</#if>
    <#return false/>
</#function>

<#-- get the substance components for only *SUBSTANCE and *REFERENCE_SUBSTANCE from a Mixture composition product -->
<#function getComponents productComposition id="">
<#local substanceComponents = [] />
<#local substanceComp = [] />

<#if !(productComposition?has_content)>
  <#return [] />
</#if>

<#if productComposition?has_content>

    <#if id="Qualitative and quantitative information on the composition of the product">
    
      <#list productComposition as composition>
        <#if composition?has_content>
      
          <#local componentList = composition.Components.Components/>
          
          <#list componentList as component>
            <#if component?has_content>
              <#if isSubstanceOrReferenceSubstance(component, "componentProduct")>
                <#local substanceComponents = substanceComponents + [component]/>
              </#if>	
            </#if>			
          </#list>
        </#if>
      </#list>

    <#elseif id="Meta SPC Product composition">

        <#local componentList = productComposition.Components.Components/>    
          <#list componentList as component>
          <#if isSubstanceOrReferenceSubstance(component, "componentProduct")>
            <#if component?has_content>
              <#local substanceComponents = substanceComponents + [component]/>         
            </#if>	
          </#if>		
          </#list>
    </#if>
        
</#if>

	<#return substanceComponents/>
</#function>

<#-- get the substance components for only *SUBSTANCE and *REFERENCE_SUBSTANCE from a Mixture composition summary -->
<#function getSummaryFamilyComposition mainMixtureCompositionSummaryList summaryType="">
<#local summaryComponents = [] />

<#if !(mainMixtureCompositionSummaryList?has_content)>
  <#return [] />
</#if>

<#list mainMixtureCompositionSummaryList as composition>
  <#if composition?has_content>
 
    <#local componentList = composition.ProductSummaryComposition.Composition/>
    
    <#list componentList as component>
      <#if component?has_content>
        <#if isFamilyComposition(composition) && summaryType=="family"> 

          <#if isSubstanceOrReferenceSubstance(component, "componentSummary")>
            <#local summaryComponents = summaryComponents + [component]/>
          </#if>

        <#elseif isMetaSPCcomposition(composition) && summaryType=="metaspc"> 

          <#if isSubstanceOrReferenceSubstance(component, "componentSummary")>
            <#local summaryComponents = summaryComponents + [component]/>
          </#if>

        </#if>	
      </#if>			
    </#list>
  </#if>
</#list>
	<#return summaryComponents/>
</#function>


<#function isSubstanceOrReferenceSubstance component componentDefinition="">

<#if componentDefinition=="componentProduct">
<#local componentType = iuclid.getDocumentForKey(component.Reference)/>
<#elseif componentDefinition=="componentSummary">
<#local componentType = iuclid.getDocumentForKey(component.Name)/>
</#if>

  <#if componentType?has_content>
  <#if componentType.documentType=="SUBSTANCE" || componentType.documentType=="REFERENCE_SUBSTANCE">
      <#return true >
    <#else>
      <#return false />
  </#if>
  </#if>
      <#return false />
</#function>

<#function getSitesBelongingToSupplier sitesList suppliersFirstKey>

  <#assign mylinkedLE = []/>
  <#assign mynewle = []/>

  <#if sitesList?has_content>
    <#list sitesList as sites>
      <#if sites?has_content>
        <#assign linkedSite = iuclid.getDocumentForKey(sites.ReferenceSite)/>
        <#if linkedSite?has_content>
          <#local linkedLegalEntity = iuclid.getDocumentForKey(linkedSite.GeneralInfo.OwnerLegalEntity)/>
          <#if linkedLegalEntity?has_content && linkedLegalEntity.documentKey.uuid == suppliersFirstKey>
            <#assign mynewle = mynewle + [linkedSite]/>
          </#if>
          <#assign mylinkedLE = mylinkedLE + [linkedLegalEntity.documentKey.uuid] />         
        </#if>
      </#if>
    </#list>
  </#if>

  <#return mynewle/>
</#function>


<#function isSameLocationAsSupplier locationLegalEntity supplierLegalEntity="">

  <#if !(legalEntityuuid)?has_content>
  <#return false/>
  <#else>

    <#local supplierUUID><@com.text legalEntityuuid/></#local>
    <#if locationLegalEntity?has_content && locationLegalEntity.documentKey.uuid == supplierLegalEntity>
        <#return true>
      <#else>
        <#return false>
    </#if>

  </#if>
    <#return false/>
</#function>

<#function isSubstanceComponent componentKey>
  <#if componentKey.documentType=="SUBSTANCE">
    <#return true>
  <#else>
    <#return false>
  </#if>
    <#return false>
</#function>

<#function getFirstHistoryOnly _subject>

    <#local historyList = iuclid.getHistoryForDocumentKey(_subject.documentKey) />
	
        
        <#if !(historyList)?has_content>
            <#return [] />
        </#if>
        
        <#if historyList?has_content>		
            <#list historyList as history>	
                <#if !(history)?has_content>
                    <#return [] />	
                    <#else/>
                        <#return historyList[0] />					
                </#if>
            </#list>
        </#if>	
        
	<#return [] />			
</#function>

<#-------------------------------------->
<#-- macros for immediate data output -->
<#-------------------------------------->

<#macro macroForPopulatingDossierHeader _dossierHeader>
<#assign authNumber = [] />
<#assign refAssetNumber = [] />
<#assign expiryDate = [] />
<#assign dateOfAuth = [] />


  <#if _dossierHeader?has_content>
      <#if _dossierHeader.SpecificSubmissions.AuthorisationDetails.AuthorisationNumber?has_content>
        <#assign authNumber><@com.text _dossierHeader.SpecificSubmissions.AuthorisationDetails.AuthorisationNumber/></#assign>
      </#if>

      <#if _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber?has_content>
        <#assign refAssetNumber><@com.text _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber/></#assign>
      </#if>

      <#if _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber?has_content>
        <#assign expiryDate><@com.text _dossierHeader.SpecificSubmissions.AuthorisationDetails.ExpiryDate/></#assign>
      </#if>

      <#if _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber?has_content>
        <#assign dateOfAuth><@com.text _dossierHeader.SpecificSubmissions.AuthorisationDetails.AuthorisationDate/></#assign>
      </#if>
  </#if>
</#macro>

<#macro productTypes usesList locale="en">
  <#assign phrases = productTypeFunction(usesList)/>
    <#list phrases as phrase>
        <para>${phrase}</para>
    </#list>
</#macro>

<#------------------------------------------>
<#-- alternative outputs to common_macros -->
<#------------------------------------------>

<#macro picklistMultipleWoutSemiColon picklistMultipleValue >
<#compress>
	<#if picklistMultipleValue?has_content && picklistMultipleValue?node_type=="picklist_multi">
		<#list picklistMultipleValue as item>
			<@com.picklist item/>
			<#if item_has_next><?linebreak?></#if>
		</#list>

      <#elseif picklistMultipleValue?has_content && picklistMultipleValue?node_type=="picklist_single" >
      <@com.picklist picklistMultipleValue/>
	</#if>
</#compress>
</#macro>


<#macro picklisttest picklistValue languageLocale="" printOtherPhrase=false printDescription=true printRemarks=true>
	<#compress>
		<#escape x as x?html>

			<#local localizedPhrase = iuclid.localizedPhraseDefinitionFor(picklistValue.code, "${languageLocale}") />
			
			<#if localizedPhrase?has_content>

				<#if !localizedPhrase.open || !(localizedPhrase.text?matches("other:")) || printOtherPhrase>
					${localizedPhrase.text}<#t>  
				</#if>

				<#if localizedPhrase.open && picklistValue.otherText?has_content>
					${picklistValue.otherText}<#t>
				</#if>

					<#if printDescription && localizedPhrase.description?has_content>
						[${localizedPhrase.description}]
					</#if>
				</#if>

			<#if printRemarks && picklistValue.remarks?has_content>
				- ${picklistValue.remarks}
			</#if>
			<#lt>

		</#escape>
	</#compress>
</#macro>
